pub fn measure(path: &Path, config: Config) -> Result<KmapSize>Expand description
Measure the current text fields of every node in a Kweb root.
This opens the database, so callers must enforce any application-specific offline or mutual-exclusion policy before calling it.